==> haskell-gi-0.24.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-gi
version:              0.24.1
visibility:           public
id:                   haskell-gi-0.24.1-24qFHZ11NX58wuBt2GmtYe
key:                  haskell-gi-0.24.1-24qFHZ11NX58wuBt2GmtYe
license:              LGPL-2.1-only
maintainer:           Iñaki García Etxebarria (inaki@blueleaf.cc)
author:
    Will Thompson,
    Iñaki García Etxebarria,
    Jonas Platte

stability:            Experimental
homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    Generate Haskell bindings for GObject Introspection capable libraries

description:
    Generate Haskell bindings for GObject Introspection capable libraries. This includes most notably
    Gtk+, but many other libraries in the GObject ecosystem provide introspection data too.

category:             Development
abi:                  078f28ff327ca4954176a046e22c89f8
exposed:              True
exposed-modules:
    Data.GI.CodeGen.API Data.GI.CodeGen.Cabal
    Data.GI.CodeGen.CabalHooks Data.GI.CodeGen.Callable
    Data.GI.CodeGen.Code Data.GI.CodeGen.CodeGen Data.GI.CodeGen.Config
    Data.GI.CodeGen.Constant Data.GI.CodeGen.Conversions
    Data.GI.CodeGen.CtoHaskellMap Data.GI.CodeGen.EnumFlags
    Data.GI.CodeGen.Fixups Data.GI.CodeGen.GObject
    Data.GI.CodeGen.GType Data.GI.CodeGen.GtkDoc
    Data.GI.CodeGen.Haddock Data.GI.CodeGen.Inheritance
    Data.GI.CodeGen.LibGIRepository Data.GI.CodeGen.ModulePath
    Data.GI.CodeGen.OverloadedLabels Data.GI.CodeGen.OverloadedMethods
    Data.GI.CodeGen.OverloadedSignals Data.GI.CodeGen.Overrides
    Data.GI.CodeGen.PkgConfig Data.GI.CodeGen.ProjectInfo
    Data.GI.CodeGen.Properties Data.GI.CodeGen.Signal
    Data.GI.CodeGen.Struct Data.GI.CodeGen.SymbolNaming
    Data.GI.CodeGen.Transfer Data.GI.CodeGen.Type Data.GI.CodeGen.Util
    Data.GI.GIR.Alias Data.GI.GIR.Allocation Data.GI.GIR.Arg
    Data.GI.GIR.BasicTypes Data.GI.GIR.Callable Data.GI.GIR.Callback
    Data.GI.GIR.Constant Data.GI.GIR.Deprecation
    Data.GI.GIR.Documentation Data.GI.GIR.Enum Data.GI.GIR.Field
    Data.GI.GIR.Flags Data.GI.GIR.Function Data.GI.GIR.Interface
    Data.GI.GIR.Method Data.GI.GIR.Object Data.GI.GIR.Parser
    Data.GI.GIR.Property Data.GI.GIR.Repository Data.GI.GIR.Signal
    Data.GI.GIR.Struct Data.GI.GIR.Type Data.GI.GIR.Union
    Data.GI.GIR.XMLUtils

hidden-modules:       Paths_haskell_gi
import-dirs:          /usr/lib/ghc-8.10.1/site-local/haskell-gi-0.24.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/haskell-gi-0.24.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/haskell-gi-0.24.1
hs-libraries:         HShaskell-gi-0.24.1-24qFHZ11NX58wuBt2GmtYe
extra-libraries:      girepository-1.0 gobject-2.0 glib-2.0
include-dirs:
    /usr/include/gobject-introspection-1.0 /usr/include/glib-2.0
    /usr/lib/glib-2.0/include

depends:
    Cabal-3.2.0.0 ansi-terminal-0.10.3-uz3rqV2qrpKTwCWnkS9TH
    attoparsec-0.13.2.4-9VgtT9nUy8gHHw0166EHAk base-4.14.0.0
    bytestring-0.10.10.0 containers-0.6.2.1 directory-1.3.6.0
    filepath-1.4.2.1 haskell-gi-base-0.24.0-4dUFq6dUCW6Hkq40UHk45s
    mtl-2.2.2 pretty-show-1.10-5aohyDmEADG9yJ0U7kMN1J process-1.6.8.2
    regex-tdfa-1.3.1.0-HPvdYMAdCmlIUvSVzIJAm1
    safe-0.3.19-CK0lfIX5mWD7fu30IXX07t text-1.2.3.2
    transformers-0.5.6.2 xdg-basedir-0.2.2-LyAMs9O5AW29vJKeVF5oeE
    xml-conduit-1.9.0.0-GdNs5VIEZVb2Dq1MpVYwBV

haddock-interfaces:   /usr/share/doc/haskell-gi/html/haskell-gi.haddock
haddock-html:         /usr/share/doc/haskell-gi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gi-0.24.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-gi
version:              0.24.1
visibility:           public
id:                   haskell-gi-0.24.1-9oASUDlhbJ8EDvfzwGQNxH
key:                  haskell-gi-0.24.1-9oASUDlhbJ8EDvfzwGQNxH
license:              LGPL-2.1-only
maintainer:           Iñaki García Etxebarria (inaki@blueleaf.cc)
author:
    Will Thompson,
    Iñaki García Etxebarria,
    Jonas Platte

stability:            Experimental
homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    Generate Haskell bindings for GObject Introspection capable libraries

description:
    Generate Haskell bindings for GObject Introspection capable libraries. This includes most notably
    Gtk+, but many other libraries in the GObject ecosystem provide introspection data too.

category:             Development
abi:                  e30563b1153fd121b74cf03efdd06949
exposed:              True
exposed-modules:
    Data.GI.CodeGen.API Data.GI.CodeGen.Cabal
    Data.GI.CodeGen.CabalHooks Data.GI.CodeGen.Callable
    Data.GI.CodeGen.Code Data.GI.CodeGen.CodeGen Data.GI.CodeGen.Config
    Data.GI.CodeGen.Constant Data.GI.CodeGen.Conversions
    Data.GI.CodeGen.CtoHaskellMap Data.GI.CodeGen.EnumFlags
    Data.GI.CodeGen.Fixups Data.GI.CodeGen.GObject
    Data.GI.CodeGen.GType Data.GI.CodeGen.GtkDoc
    Data.GI.CodeGen.Haddock Data.GI.CodeGen.Inheritance
    Data.GI.CodeGen.LibGIRepository Data.GI.CodeGen.ModulePath
    Data.GI.CodeGen.OverloadedLabels Data.GI.CodeGen.OverloadedMethods
    Data.GI.CodeGen.OverloadedSignals Data.GI.CodeGen.Overrides
    Data.GI.CodeGen.PkgConfig Data.GI.CodeGen.ProjectInfo
    Data.GI.CodeGen.Properties Data.GI.CodeGen.Signal
    Data.GI.CodeGen.Struct Data.GI.CodeGen.SymbolNaming
    Data.GI.CodeGen.Transfer Data.GI.CodeGen.Type Data.GI.CodeGen.Util
    Data.GI.GIR.Alias Data.GI.GIR.Allocation Data.GI.GIR.Arg
    Data.GI.GIR.BasicTypes Data.GI.GIR.Callable Data.GI.GIR.Callback
    Data.GI.GIR.Constant Data.GI.GIR.Deprecation
    Data.GI.GIR.Documentation Data.GI.GIR.Enum Data.GI.GIR.Field
    Data.GI.GIR.Flags Data.GI.GIR.Function Data.GI.GIR.Interface
    Data.GI.GIR.Method Data.GI.GIR.Object Data.GI.GIR.Parser
    Data.GI.GIR.Property Data.GI.GIR.Repository Data.GI.GIR.Signal
    Data.GI.GIR.Struct Data.GI.GIR.Type Data.GI.GIR.Union
    Data.GI.GIR.XMLUtils

hidden-modules:       Paths_haskell_gi
import-dirs:          /usr/lib/ghc-8.10.1/site-local/haskell-gi-0.24.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/haskell-gi-0.24.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/haskell-gi-0.24.1
hs-libraries:         HShaskell-gi-0.24.1-9oASUDlhbJ8EDvfzwGQNxH
extra-libraries:      girepository-1.0 gobject-2.0 glib-2.0
include-dirs:
    /usr/include/gobject-introspection-1.0 /usr/include/glib-2.0
    /usr/lib/glib-2.0/include

depends:
    Cabal-3.2.0.0 ansi-terminal-0.10.3-uz3rqV2qrpKTwCWnkS9TH
    attoparsec-0.13.2.4-9VgtT9nUy8gHHw0166EHAk base-4.14.0.0
    bytestring-0.10.10.0 containers-0.6.2.1 directory-1.3.6.0
    filepath-1.4.2.1 haskell-gi-base-0.24.1-IbO4wtSzKKb5Q96TmnBMm2
    mtl-2.2.2 pretty-show-1.10-5aohyDmEADG9yJ0U7kMN1J process-1.6.8.2
    regex-tdfa-1.3.1.0-HPvdYMAdCmlIUvSVzIJAm1
    safe-0.3.19-CK0lfIX5mWD7fu30IXX07t text-1.2.3.2
    transformers-0.5.6.2 xdg-basedir-0.2.2-LyAMs9O5AW29vJKeVF5oeE
    xml-conduit-1.9.0.0-GdNs5VIEZVb2Dq1MpVYwBV

haddock-interfaces:   /usr/share/doc/haskell-gi/html/haskell-gi.haddock
haddock-html:         /usr/share/doc/haskell-gi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
